==> phpAdsNew_1.6.2.tar.gz: phpAdsNew_1.6.2/italian.inc.php <==
<?

$strHome = "Home";
$date_format = "%d/%m/%Y";
$time_format = "%H:%i:%S";
$strMySQLError = "Errore MySQl:";
$strAdminstration = "Amministrazione";
$strAddClient = "Aggiungi nuovo utente";
$strModifyClient = "Modifica utente";
$strDeleteClient = "Cancella utente";
$strViewClientStats = "Visualizza statistiche dell'utente";
$strClientName = "Utente";
$strContact = "Contatto";
$strEMail = "E-Mail";
$strViews = "Visualizzazioni";
$strClicks = "Click";
$strTotalViews = "Visualizzazioni Totali";
$strTotalClicks = "Click Totali";
$strCTR = "Click-Throuh Ratio";
$strTotalClients = "Total clients";
$strActiveClients = "Active clients";
$strActiveBanners = "Active banners";
$strLogout = "Logout";
$strCreditStats = "Credit Stats";
$strViewCredits = "Adview credits";   
$strClickCredits = "Adclick credits";
$strPrevious = "Previous";
$strNext = "Next";
$strNone = "None";
$strViewsPurchased = "Visualizzazioni Acquistate";
$strClicksPurchased = "Click Acquistati";
$strDaysPurchased = "AdDays purchased";
$strHTML = "HTML";
$strAddSep = "Compilare ENTRAMBE i campi sovrastanti OPPURE quello sottostante!";
$strTextBelow = "Testo sotto l'immagine";
$strSubmit = "Submit ad";
$strUsername = "Username";
$strPassword = "Password";
$strBannerAdmin = "Banner adminstration for";
$strBannerAdminAcl = "Banner ACL adminstration for";
$strNoBanners = "Nessun banner trovato";
$strBanner = "Banner";
$strCurrentBanner = "Banner attuale";
$strDelete = "Cancella";
$strAddBanner  = "Aggiungi nuovo banner";
$strModifyBanner  = "Modifica banner";
$strModifyBannerAcl  = "Modify banner ACL";
$strURL = "Link (incl. http://)";
$strKeyword = "Parola chiave";
$strWeight = "Weight";
$strAlt = "Testo Alternativo";
$strAccessDenied = "Accesso negato";
$strNotAdmin = "Non hai i privilegi di Amministratore";
$strClientAdded = "L'utente e' stato aggiunto.";
$strClientModified = "L'utente e' stato modificato.";
$strClientDeleted = "L'utente e' stato cancellato.";
$strBannerAdmin = "Amministrazione Banner";
$strBannerAdded = "Il banner e' stato aggiunto.";
$strBannerModified = "Il banner e' stato modificato.";
$strBannerDeleted = "Il banner e' stato cancellato.";
$strBannerChanged = "Il banner e' stato cambiato.";
$strStats = "Statistiche";
$strDailyStats = "Statistiche quotidiane";
$strDetailStats = "Statistiche dettagliate";
$strCreditStats = "Credit statistics";
$strActive = "attivo";
$strActivate = "Attiva";
$strDeActivate = "Disattiva";
$strAuthentification = "Autentificazione";
$strGo = "Vai";
$strLinkedTo = "linkato a";
$strBannerID = "ID Banner";
$strClientID = "ID Utente";
$strMailSubject = "Statistiche phpAds";
$strMailSubjectDeleted = "Deactivated Ads";
$strMailHeader = 'Egr. Sig. ".$clients[$i][contact].",\n';
$strMailBannerStats = 'ecco le statistiche dei banner per ".$clients[$i][clientname].":';
$strMailFooter = 'Distinti saluti,\n   $phpAds_admin_fullname';
$strMailNothingLeft = 'Tutte le visualizzazioni da Voi acquistate sono state eseguite, pertanto i Vostri banner sono stati disabilitati.\n\nSe desiderate acquistare altre visualizzazioni Vi preghiamo di contattarci.';
$strLogMailSent = "[phpAds] Statistiche inviate correttamente.";
$strLogErrorClients = "[phpAds] Si e\' verificato un errore nel tentativo di recuperare gli utenti dal database.";
$strLogErrorBanners = "[phpAds] Si e\' verificato un errore nel tentativo di recuperare i banner dal database.";
$strLogErrorViews = "[phpAds] Si e\' verificato un errore nel tentativo di recuperare le visualizzazioni dal database.";
$strLogErrorClicks = "[phpAds] Si e\' verificato un errore nel tentativo di recuperare i clicks dal database.";
$strLogErrorDisactivate = "[phpAds] Si e\' verificato un errore nel tentativo di disattivare un banner.";
$strRatio = "Percentuale di Click-Through";
$strChooseBanner = "Scegliere il tipo di banner.";
$strMySQLBanner = "Banner memorizzato nel database MySQL";
$strURLBanner = "Banner situato ad un altro URL";
$strHTMLBanner = "HTML banner";
$strNewBannerFile = "Nuovo file del banner";
$strNewBannerURL = "Nuovo URL del banner (incl. http://)";
$strWidth = "Larghezza";
$strHeight = "Altezza";
$strTotalViews7Days = "Total AdViews in past 7 days";
$strTotalClicks7Days = "Total AdClicks in past 7 days";
$strAvgViews7Days = "Average AdViews in past 7 days";
$strAvgClicks7Days = "Average AdClicks in past 7 days";
$strTopTenHosts = "Top ten requesting hosts";
$strConfirmDeleteClient = "Do you really want to delete this client?";
$strClientIP = "Client IP";
$strUserAgent = "User agent regexp";
$strWeekDay = "Week day (0 - 6)";
$strDomain = "Domain (excluding dot)";
$strSource = "Source";
$strTime = "Time";
$strAllow = "Allow";
$strDeny = "Deny";
$strResetStats = "Reset Statistics";
?>

==> phpAdsNew_1.8.0.tar.gz: phpAdsNew_1.8.0/italian.inc.php <==
<?

$strHome = "Home";
$date_format = "%d/%m/%Y";
$time_format = "%H:%i:%S";
$strMySQLError = "Errore MySQl:";
$strAdminstration = "Amministrazione";
$strAddClient = "Aggiungi nuovo utente";
$strModifyClient = "Modifica utente";
$strDeleteClient = "Cancella utente";
$strViewClientStats = "Visualizza statistiche dell'utente";
$strClientName = "Utente";
$strContact = "Contatto";
$strEMail = "E-Mail";
$strViews = "Visualizzazioni";
$strClicks = "Click";
$strTotalViews = "Visualizzazioni Totali";
$strTotalClicks = "Click Totali";
$strCTR = "Click-Through Ratio";
$strTotalClients = "Total clients";
$strActiveClients = "Active clients";
$strActiveBanners = "Active banners";
$strLogout = "Logout";
$strCreditStats = "Credit Stats";
$strViewCredits = "Adview credits";   
$strClickCredits = "Adclick credits";
$strPrevious = "Previous";
$strNext = "Next";
$strNone = "None";
$strViewsPurchased = "Visualizzazioni Acquistate";
$strClicksPurchased = "Click Acquistati";
$strDaysPurchased = "AdDays purchased";
$strHTML = "HTML";
$strAddSep = "Compilare ENTRAMBE i campi sovrastanti OPPURE quello sottostante!";
$strTextBelow = "Testo sotto l'immagine";
$strSubmit = "Submit ad";
$strUsername = "Username";
$strPassword = "Password";
$strBannerAdmin = "Banner adminstration for";
$strBannerAdminAcl = "Banner ACL adminstration for";
$strNoBanners = "Nessun banner trovato";
$strBanner = "Banner";
$strCurrentBanner = "Banner attuale";
$strDelete = "Cancella";
$strAddBanner  = "Aggiungi nuovo banner";
$strModifyBanner  = "Modifica banner";
$strModifyBannerAcl  = "Modify banner ACL";
$strURL = "Link (incl. http://)";
$strKeyword = "Parola chiave";
$strWeight = "Weight";
$strAlt = "Testo Alternativo";
$strAccessDenied = "Accesso negato";
$strNotAdmin = "Non hai i privilegi di Amministratore";
$strClientAdded = "L'utente e' stato aggiunto.";
$strClientModified = "L'utente e' stato modificato.";
$strClientDeleted = "L'utente e' stato cancellato.";
$strBannerAdmin = "Amministrazione Banner";
$strBannerAdded = "Il banner e' stato aggiunto.";
$strBannerModified = "Il banner e' stato modificato.";
$strBannerDeleted = "Il banner e' stato cancellato.";
$strBannerChanged = "Il banner e' stato cambiato.";
$strStats = "Statistiche";
$strDailyStats = "Statistiche quotidiane";
$strDetailStats = "Statistiche dettagliate";
$strCreditStats = "Credit statistics";
$strActive = "attivo";
$strActivate = "Attiva";
$strDeActivate = "Disattiva";
$strAuthentification = "Autentificazione";
$strGo = "Vai";
$strLinkedTo = "linkato a";
$strBannerID = "ID Banner";
$strClientID = "ID Utente";
$strMailSubject = "Statistiche phpAds";
$strMailSubjectDeleted = "Deactivated Ads";
$strMailHeader = 'Egr. Sig. ".$clients[$i][contact].",\n';
$strMailBannerStats = 'ecco le statistiche dei banner per ".$clients[$i][clientname].":';
$strMailFooter = 'Distinti saluti,\n   $phpAds_admin_fullname';
$strMailNothingLeft = 'Tutte le visualizzazioni da Voi acquistate sono state eseguite, pertanto i Vostri banner sono stati disabilitati.\n\nSe desiderate acquistare altre visualizzazioni Vi preghiamo di contattarci.';
$strLogMailSent = "[phpAds] Statistiche inviate correttamente.";
$strLogErrorClients = "[phpAds] Si e\' verificato un errore nel tentativo di recuperare gli utenti dal database.";
$strLogErrorBanners = "[phpAds] Si e\' verificato un errore nel tentativo di recuperare i banner dal database.";
$strLogErrorViews = "[phpAds] Si e\' verificato un errore nel tentativo di recuperare le visualizzazioni dal database.";
$strLogErrorClicks = "[phpAds] Si e\' verificato un errore nel tentativo di recuperare i clicks dal database.";
$strLogErrorDisactivate = "[phpAds] Si e\' verificato un errore nel tentativo di disattivare un banner.";
$strRatio = "Percentuale di Click-Through";
$strChooseBanner = "Scegliere il tipo di banner.";
$strMySQLBanner = "Banner memorizzato nel database MySQL";
$strURLBanner = "Banner situato ad un altro URL";
$strHTMLBanner = "HTML banner";
$strNewBannerFile = "Nuovo file del banner";
$strNewBannerURL = "Nuovo URL del banner (incl. http://)";
$strWidth = "Larghezza";
$strHeight = "Altezza";
$strTotalViews7Days = "Total AdViews in past 7 days";
$strTotalClicks7Days = "Total AdClicks in past 7 days";
$strAvgViews7Days = "Average AdViews in past 7 days";
$strAvgClicks7Days = "Average AdClicks in past 7 days";
$strTopTenHosts = "Top ten requesting hosts";
$strConfirmDeleteClient = "Do you really want to delete this client?";
$strClientIP = "Client IP";
$strUserAgent = "User agent regexp";
$strWeekDay = "Week day (0 - 6)";
$strDomain = "Domain (excluding dot)";
$strSource = "Source";
$strTime = "Time";
$strAllow = "Allow";
$strDeny = "Deny";
$strResetStats = "Reset Statistics";
$strConfirmResetStats = "Do you really want to reset stats for this client ?";
$strExpiration = "Expiration";
$strDaysLeft = "Days left";
$strEstimated = "Estimated expiration";
$strConfirm = "Are you sure ?";
$strBannerNoStats = "No statistics available for this banner!";
$strWeek = "Week";
$strWeeklyStats = "Weekly statistics";
$strWeekDay = "Weekday";
$strDate = "Date";
$strCTRShort = "CTR";
$strDayShortCuts=array("Su","Mo","Tu","We","Th","Fr","Sa");
$strShowWeeks="Max. weeks to display";
$strAll="all";
$strAvg="Avg.";
$strHourly="Views/Clicks by hour";
$strTotal = "Total";
$strUnlimited = "Unlimited";

?>
